@@ -1,25 +1,21 @@
 // class cl_wht_from_rcpointer2_to_rcpointer.
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
-#include "cl_rcpointer2_hashweak_rcpointer.h"
+#include "base/hash/cl_rcpointer2_hashweak_rcpointer.h"
 
 
 // Implementation.
 
-#include "cl_hash2weak.h"
+#include "base/hash/cl_hash2weak.h"
 
 namespace cln {
 
 static void cl_weak_hashtable_from_rcpointer2_to_rcpointer_destructor (cl_heap* pointer)
 {
-#if (defined(__mips__) || defined(__mips64__)) && !defined(__GNUC__) // workaround SGI CC bug
-	(*(cl_heap_weak_hashtable_from_rcpointer2_to_rcpointer*)pointer).~cl_heap_weak_hashtable_2();
-#else
 	(*(cl_heap_weak_hashtable_from_rcpointer2_to_rcpointer*)pointer).~cl_heap_weak_hashtable_from_rcpointer2_to_rcpointer();
-#endif
 }
 
 cl_class cl_class_weak_hashtable_from_rcpointer2_to_rcpointer = {
