@@ -1,7 +1,7 @@
 // operator>>.
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/string.h"
@@ -10,7 +10,7 @@
 // Implementation.
 
 #include "cln/io.h"
-#include "cl_spushstring.h"
+#include "base/string/cl_spushstring.h"
 #include <cctype>
 
 namespace cln {
@@ -19,12 +19,12 @@ std::istream& operator>> (std::istream& stream, cl_string& str)
 {
 	var cl_spushstring buffer;
 	var int n = stream.width();
-	// Handling of eofp is tricky: EOF is reached when (!stream.good()) || (stream.get()==EOF).
+	// Handling of eofp is tricky: EOF is reached when (!stream.good()) || (stream.eof()).
 	int c;
 	// Skip whitespace.
 	while (stream.good()) {
 		c = stream.get();
-		if (c==EOF)
+		if (stream.eof())
 			break;
 		if (!isspace(c)) {
 			if (--n == 0) {
@@ -40,7 +40,7 @@ std::istream& operator>> (std::istream& stream, cl_string& str)
 	// Read non-whitespace.
 	while (stream.good()) {
 		c = stream.get();
-		if (c==EOF)
+		if (stream.eof())
 			break;
 		if (isspace(c)) {
 			stream.unget();
