@@ -1,7 +1,7 @@
 // cl_F_to_DF().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/float.h"
@@ -9,7 +9,7 @@
 
 // Implementation.
 
-#include "cl_F.h"
+#include "float/cl_F.h"
 
 namespace cln {
 
