@@ -1,7 +1,7 @@
 // read_float().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/float_io.h"
@@ -10,33 +10,33 @@
 // Implementation.
 
 #include "cln/integer.h"
-#include "cl_I.h"
+#include "integer/cl_I.h"
 #include "cln/rational.h"
-#include "cl_RA.h"
+#include "rational/cl_RA.h"
 #include "cln/float.h"
 #include "cln/sfloat.h"
 #include "cln/ffloat.h"
 #include "cln/dfloat.h"
 #include "cln/lfloat.h"
-#include "cl_F.h"
-#include "cl_SF.h"
-#include "cl_FF.h"
-#include "cl_DF.h"
-#include "cl_LF.h"
+#include "float/cl_F.h"
+#include "float/sfloat/cl_SF.h"
+#include "float/ffloat/cl_FF.h"
+#include "float/dfloat/cl_DF.h"
+#include "float/lfloat/cl_LF.h"
 
 namespace cln {
 
-const cl_F read_float (unsigned int base, float_format_t prec, cl_signean sign, const char * string, uintL index1, uintL index4, uintL index2, uintL index3)
+const cl_F read_float (unsigned int base, float_format_t prec, cl_signean sign, const char * string, uintC index1, uintC index4, uintC index2, uintC index3)
 {
 	var cl_I exponent;
 	{
-		var uintL exp_len = index2-index4; // Anzahl Stellen des Exponenten
+		var uintC exp_len = index2-index4; // Anzahl Stellen des Exponenten
 		if (exp_len > 0) {
 			var const char * ptr = &string[index4]; // zeigt auf den Exponentmarker
 			ptr++; exp_len--; // Exponentmarker überlesen
 			var cl_signean exp_sign = 0; // Exponenten-Vorzeichen
 			switch (*ptr) {
-				case '-': exp_sign = ~exp_sign; // Vorzeichen := negativ
+				case '-': exp_sign = ~exp_sign; // fallthrough
 				case '+': ptr++; exp_len--; // Exponenten-Vorzeichen überlesen
 				default: ;
 			}
