@@ -35,16 +35,16 @@ uint32 cl_I_to_UL (const cl_I& obj)
 		var uintC len = bn->length;
 		if ((sintD)mspref(arrayMSDptr(bn->data,len),0) < 0)
 			goto bad;
-		#define IF_LENGTH(i)  \
-		  if (bn_minlength <= i) /* genau i Digits überhaupt möglich? */\
-		    if (len == i) /* genau i Digits? */				\
-		      /* 2^((i-1)*intDsize-1) <= obj < 2^(i*intDsize-1) */	\
-		      if ( (i*intDsize-1 > 32)					\
-		           && ( ((i-1)*intDsize-1 >= 32)			\
-		                || (mspref(arrayMSDptr(bn->data,len),0) >= (uintD)bitc(32-(i-1)*intDsize)) \
-		         )    )							\
-		        goto bad;						\
-			else
+		#define IF_LENGTH(i)							\
+		  if ((bn_minlength <= i) /* genau i Digits überhaupt möglich? */	\
+		    && (len == i) /* genau i Digits? */					\
+		    /* 2^((i-1)*intDsize-1) <= obj < 2^(i*intDsize-1) */		\
+		    && ( (i*intDsize-1 > 32)						\
+		         && ( ((i-1)*intDsize-1 >= 32)					\
+		              || (mspref(arrayMSDptr(bn->data,len),0) >= (uintD)bitc(32-(i-1)*intDsize)) \
+		     ) )    )								\
+		    goto bad;								\
+		    else
 		IF_LENGTH(1)
 			return get_uint1D_Dptr(arrayLSDptr(bn->data,1));
 		IF_LENGTH(2)
