@@ -1,7 +1,7 @@
 // exquo().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/integer.h"
@@ -9,7 +9,7 @@
 
 // Implementation.
 
-#include "cl_I.h"
+#include "integer/cl_I.h"
 
 namespace cln {
 
