@@ -1,7 +1,7 @@
 // minusp().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/integer.h"
@@ -10,7 +10,7 @@
 // Implementation.
 
 #define minusp inline_minusp
-#include "cl_I.h"
+#include "integer/cl_I.h"
 #undef minusp
 
 namespace cln {
