@@ -1,7 +1,7 @@
 // truncate1().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/real.h"
@@ -9,7 +9,7 @@
 
 // Implementation.
 
-#include "cl_R.h"
+#include "real/cl_R.h"
 #include "cln/rational.h"
 
 namespace cln {
