@@ -1,7 +1,7 @@
 // log().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/real.h"
@@ -9,8 +9,8 @@
 
 // Implementation.
 
-#include "cl_N.h"
-#include "cl_R.h"
+#include "base/cl_N.h"
+#include "real/cl_R.h"
 #include "cln/rational.h"
 #include "cln/float.h"
 
@@ -30,7 +30,7 @@ const cl_R log (const cl_R& a, const cl_R& b)
 	Mutable(cl_R,b);
 	if (rationalp(b)) {
 		// b rational
-		if (eq(b,1)) { cl_error_division_by_0(); }
+		if (eq(b,1)) { throw division_by_0_exception(); }
 		if (rationalp(a)) {
 			// a,b beide rational
 			var cl_RA l;
