@@ -1,7 +1,7 @@
 // cl_SV_number debugging support.
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 
@@ -11,7 +11,7 @@
 #include "cln/output.h"
 #include "cln/SV_number.h"
 #include "cln/io.h"
-#include "cl_SV_io.h"
+#include "vector/cl_SV_io.h"
 
 namespace cln {
 
@@ -29,7 +29,7 @@ static void dprint (cl_heap* pointer)
 	print_vector(cl_debugout,default_print_flags,&print_for_debug,obj);
 }
 AT_INITIALIZATION(dprint_SV_number)
-{ cl_register_type_printer(cl_class_svector_number,dprint); }
+{ extern cl_class& cl_class_svector_number(); cl_class_svector_number().dprint = dprint; }
 
 // This dummy links in this module when <cln/SV_number.h> requires it.
 int cl_SV_number_debug_module;
