@@ -1,7 +1,7 @@
 // fprint() for cl_SV_ringelt.
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/SV_ringelt.h"
@@ -15,14 +15,14 @@ namespace cln {
 
 void fprint (std::ostream& stream, const cl_ring& R, const cl_SV_ringelt& vector)
 {
-	var const cl_print_flags& flags = default_print_flags;
-	var uintC len = vector.length();
+	const cl_print_flags& flags = default_print_flags;
+	std::size_t len = vector.size();
 	if (flags.vector_syntax == vsyntax_commonlisp) {
 		fprintchar(stream,'#');
 		fprintchar(stream,'(');
 	} else
 		fprintchar(stream,'[');
-	for (var uintC i = 0; i < len; i++) {
+	for (std::size_t i = 0; i < len; i++) {
 		if (i > 0) {
 			if (flags.vector_syntax == vsyntax_algebraic)
 				fprintchar(stream,',');
