@@ -1,10 +1,10 @@
 #include <cln/number.h>
 #include <cln/io.h>
 #include <cln/integer.h>
-#include "cl_DS.h"
-#include "cl_2DS.h"
+#include "base/digitseq/cl_DS.h"
+#include "base/digitseq/cl_2DS.h"
 #include <cln/random.h>
-#include "cl_random_impl.h"
+#include "base/random/cl_random_impl.h"
 #include <cstdlib>
 #include <cstring>
 #include <cln/timing.h>
@@ -23,7 +23,7 @@ int main (int argc, char * argv[])
 	uintL b_len = atoi(argv[2]);
 	if (!(a_len >= b_len && b_len > 0))
 		exit(1);
-	SAVE_NUM_STACK;
+	CL_ALLOCA_STACK;
 	uintD* a_MSDptr;
 	uintD* a_LSDptr;
 	uintD* b_MSDptr;
